@@ -394,15 +394,24 @@ class Horde_Mail_Rfc822
         $ob->mailbox = $this->_parseLocalPart();
 
         if ($this->_curr() == '@') {
-            $this->_rfc822ParseDomain($host);
-            if (strlen($host)) {
-                $ob->host = $host;
+            try {
+                $this->_rfc822ParseDomain($host);
+                if (strlen($host)) {
+                    $ob->host = $host;
+                }
+            } catch (Horde_Mail_Exception $e) {
+                if (!empty($this->_params['validate'])) {
+                    throw $e;
+                }
             }
         }
 
-        if (is_null($ob->host) &&
-            !is_null($this->_params['default_domain'])) {
-            $ob->host = $this->_params['default_domain'];
+        if (is_null($ob->host)) {
+            if (!is_null($this->_params['default_domain'])) {
+                $ob->host = $this->_params['default_domain'];
+            } elseif (!empty($this->_params['validate'])) {
+                throw new Horde_Mail_Exception('Address is missing domain.');
+            }
         }
 
         return $ob;
